# frozen_string_literal: true

module Hermes
  class LogJob < ActiveJob::Base
    queue_as :x_hermes_log
    
    def perform(*attributes)
      attributes&.first&.delete('_aj_symbol_keys')
      
      # default values
      attributes&.first[:level] = 'info' unless attributes&.first[:level].present?
      attributes&.first[:domain] = 'api' unless attributes&.first[:domain].present?
      
      # Get or create queue
      redis_key = 'redis_hermes_logs_queue'
      serialized_queue = $redis.get(redis_key)
      queue = []
      if serialized_queue
        queue = JSON.parse serialized_queue
      end

      # Push log attributes in queue
      # queue.push(*attributes)
      queue.push({ insert_one: attributes&.first})


      # Create logs if queue is full
      if queue.count >= 10
        # Log.create!(queue)
        Log.collection.bulk_write(queue.map(&:symbolize_keys))
        queue = []
      end

      # Set queue in cache if not full
      $redis.set(redis_key, queue.to_json)
    end
  end
end
